@@ -819,7 +819,7 @@ class BootstrapEngine(object):
         with open(cloud_cfg_d_file_path, 'w') as f:
             print(dedent("""\
                     # generated by image-bootstrap
-                    datasource_list: [ConfigDrive, NoCloud, Openstack, Ec2]
+                    datasource_list: [ConfigDrive, NoCloud, OpenStack, Ec2]
                     """), file=f)
 
     def _install_sshd(self):
